summaryrefslogtreecommitdiffstats
path: root/kcontrol/kcontrol
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:29:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:29:23 -0600
commit628043be55ddd2f534411d028e4f68c8fe4eaabb (patch)
tree29459652112ab6d5dfbf27ac0bbf5b86b7c83bca /kcontrol/kcontrol
parent2c01fd64ddde84a6d78b632f7f3b7c3560dc288c (diff)
downloadtdebase-628043be55ddd2f534411d028e4f68c8fe4eaabb.tar.gz
tdebase-628043be55ddd2f534411d028e4f68c8fe4eaabb.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kcontrol/kcontrol')
-rw-r--r--kcontrol/kcontrol/aboutwidget.cpp2
-rw-r--r--kcontrol/kcontrol/dockcontainer.cpp4
-rw-r--r--kcontrol/kcontrol/global.cpp4
-rw-r--r--kcontrol/kcontrol/kcrootonly.cpp4
-rw-r--r--kcontrol/kcontrol/main.cpp8
-rw-r--r--kcontrol/kcontrol/modules.cpp4
-rw-r--r--kcontrol/kcontrol/moduletreeview.cpp4
-rw-r--r--kcontrol/kcontrol/moduletreeview.h2
-rw-r--r--kcontrol/kcontrol/proxywidget.cpp4
-rw-r--r--kcontrol/kcontrol/toplevel.cpp2
10 files changed, 19 insertions, 19 deletions
diff --git a/kcontrol/kcontrol/aboutwidget.cpp b/kcontrol/kcontrol/aboutwidget.cpp
index 614a65e7b..1bfd3d127 100644
--- a/kcontrol/kcontrol/aboutwidget.cpp
+++ b/kcontrol/kcontrol/aboutwidget.cpp
@@ -82,7 +82,7 @@ AboutWidget::AboutWidget(TQWidget *parent , const char *name, TQListViewItem* ca
// set qwhatsthis help
TQWhatsThis::add(this, i18n(intro_text));
_viewer = new KHTMLPart( this, "_viewer" );
- _viewer->widget()->tqsetSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Ignored );
+ _viewer->widget()->setSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Ignored );
connect( _viewer->browserExtension(),
TQT_SIGNAL(openURLRequest(const KURL&, const KParts::URLArgs&)),
this, TQT_SLOT(slotModuleLinkClicked(const KURL&)) );
diff --git a/kcontrol/kcontrol/dockcontainer.cpp b/kcontrol/kcontrol/dockcontainer.cpp
index 9acab1129..5c4907a91 100644
--- a/kcontrol/kcontrol/dockcontainer.cpp
+++ b/kcontrol/kcontrol/dockcontainer.cpp
@@ -131,7 +131,7 @@ DockContainer::DockContainer(TQWidget *parent)
, _module(0L)
{
_busyw = new TQLabel(i18n("<big><b>Loading...</b></big>"), this);
- _busyw->tqsetAlignment(AlignCenter);
+ _busyw->setAlignment(AlignCenter);
_busyw->setTextFormat(RichText);
_busyw->setGeometry(0,0, width(), height());
addWidget( _busyw );
@@ -221,7 +221,7 @@ i18n("There are unsaved changes in the active module.\n"
ProxyWidget *widget = loadModule( module );
- KCGlobal::repairAccels( tqtopLevelWidget() );
+ KCGlobal::repairAccels( topLevelWidget() );
return ( widget!=0 );
}
diff --git a/kcontrol/kcontrol/global.cpp b/kcontrol/kcontrol/global.cpp
index 90b2179c5..b22ad2565 100644
--- a/kcontrol/kcontrol/global.cpp
+++ b/kcontrol/kcontrol/global.cpp
@@ -91,12 +91,12 @@ TQString KCGlobal::baseGroup()
if (_infocenter)
{
kdWarning() << "No K menu group with X-KDE-BaseGroup=info found ! Defaulting to Settings/Information/" << endl;
- _baseGroup = TQString::tqfromLatin1("Settings/Information/");
+ _baseGroup = TQString::fromLatin1("Settings/Information/");
}
else
{
kdWarning() << "No K menu group with X-KDE-BaseGroup=settings found ! Defaulting to Settings/" << endl;
- _baseGroup = TQString::tqfromLatin1("Settings/");
+ _baseGroup = TQString::fromLatin1("Settings/");
}
}
}
diff --git a/kcontrol/kcontrol/kcrootonly.cpp b/kcontrol/kcontrol/kcrootonly.cpp
index 9b7991298..723895de3 100644
--- a/kcontrol/kcontrol/kcrootonly.cpp
+++ b/kcontrol/kcontrol/kcrootonly.cpp
@@ -30,9 +30,9 @@ KCRootOnly::KCRootOnly(TQWidget *parent, const char *name)
TQLabel *label = new TQLabel(i18n("<big>You need super user privileges to run this control module.</big><br>"
"Click on the \"Administrator Mode\" button below."), this);
layout->addWidget(label);
- label->tqsetAlignment(AlignCenter);
+ label->setAlignment(AlignCenter);
label->setTextFormat(RichText);
- label->setMinimumSize(label->tqsizeHint());
+ label->setMinimumSize(label->sizeHint());
}
diff --git a/kcontrol/kcontrol/main.cpp b/kcontrol/kcontrol/main.cpp
index a780b608e..7a707df21 100644
--- a/kcontrol/kcontrol/main.cpp
+++ b/kcontrol/kcontrol/main.cpp
@@ -77,9 +77,9 @@ KControlApp::KControlApp()
int fontSize = toplevel->fontInfo().pointSize();
if (fontSize == 0)
fontSize = (toplevel->fontInfo().pixelSize() * 72) / pdm.logicalDpiX();
- int x = config->readNumEntry(TQString::tqfromLatin1("InitialWidth %1").arg(desk.width()),
+ int x = config->readNumEntry(TQString::fromLatin1("InitialWidth %1").arg(desk.width()),
QMIN( desk.width(), 368 + (6*pdm.logicalDpiX()*fontSize)/12 ) );
- int y = config->readNumEntry(TQString::tqfromLatin1("InitialHeight %1").arg(desk.height()),
+ int y = config->readNumEntry(TQString::fromLatin1("InitialHeight %1").arg(desk.height()),
QMIN( desk.height(), 312 + (4*pdm.logicalDpiX()*fontSize)/12 ) );
toplevel->resize(x,y);
}
@@ -91,8 +91,8 @@ KControlApp::~KControlApp()
KConfig *config = KGlobal::config();
config->setGroup("General");
TQWidget *desk = TQT_TQWIDGET(TQApplication::desktop());
- config->writeEntry(TQString::tqfromLatin1("InitialWidth %1").arg(desk->width()), toplevel->width());
- config->writeEntry(TQString::tqfromLatin1("InitialHeight %1").arg(desk->height()), toplevel->height());
+ config->writeEntry(TQString::fromLatin1("InitialWidth %1").arg(desk->width()), toplevel->width());
+ config->writeEntry(TQString::fromLatin1("InitialHeight %1").arg(desk->height()), toplevel->height());
config->sync();
}
delete toplevel;
diff --git a/kcontrol/kcontrol/modules.cpp b/kcontrol/kcontrol/modules.cpp
index 88d2124ae..5ec30ef76 100644
--- a/kcontrol/kcontrol/modules.cpp
+++ b/kcontrol/kcontrol/modules.cpp
@@ -147,7 +147,7 @@ void ConfigModule::runAsRoot()
_embedFrame->setFrameStyle( TQFrame::Box | TQFrame::Raised );
TQPalette pal( red );
pal.setColor( TQColorGroup::Background,
- _module->parentWidget()->tqcolorGroup().background() );
+ _module->parentWidget()->colorGroup().background() );
_embedFrame->setPalette( pal );
_embedFrame->setLineWidth( 2 );
_embedFrame->setMidLineWidth( 2 );
@@ -158,7 +158,7 @@ void ConfigModule::runAsRoot()
_module->hide();
_embedFrame->show();
TQLabel *_busy = new TQLabel(i18n("<big>Loading...</big>"), _embedStack);
- _busy->tqsetAlignment(AlignCenter);
+ _busy->setAlignment(AlignCenter);
_busy->setTextFormat(RichText);
_busy->setGeometry(0,0, _module->width(), _module->height());
_busy->show();
diff --git a/kcontrol/kcontrol/moduletreeview.cpp b/kcontrol/kcontrol/moduletreeview.cpp
index 144cf294f..794a69b91 100644
--- a/kcontrol/kcontrol/moduletreeview.cpp
+++ b/kcontrol/kcontrol/moduletreeview.cpp
@@ -133,9 +133,9 @@ void ModuleTreeView::fill(ModuleTreeItem *parent, const TQString &parentPath)
-TQSize ModuleTreeView::tqsizeHint() const
+TQSize ModuleTreeView::sizeHint() const
{
- return TQListView::tqsizeHint().boundedTo(
+ return TQListView::sizeHint().boundedTo(
TQSize( fontMetrics().maxWidth()*35, TQWIDGETSIZE_MAX) );
}
diff --git a/kcontrol/kcontrol/moduletreeview.h b/kcontrol/kcontrol/moduletreeview.h
index ff01cc24a..86bfecab4 100644
--- a/kcontrol/kcontrol/moduletreeview.h
+++ b/kcontrol/kcontrol/moduletreeview.h
@@ -74,7 +74,7 @@ public:
void makeSelected(ConfigModule* module);
void makeVisible(ConfigModule *module);
void fill();
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
signals:
void moduleSelected(ConfigModule*);
diff --git a/kcontrol/kcontrol/toplevel.cpp b/kcontrol/kcontrol/toplevel.cpp
index f2c00d230..cd096fa76 100644
--- a/kcontrol/kcontrol/toplevel.cpp
+++ b/kcontrol/kcontrol/toplevel.cpp
@@ -142,7 +142,7 @@ TopLevel::TopLevel(const char* name)
// help widget
_help = new HelpWidget(_dock);
- _stack->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+ _stack->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
// Restore sizes
config->setGroup("General");
diff --git a/kcontrol/kcontrol/proxywidget.cpp b/kcontrol/kcontrol/proxywidget.cpp
index dde14168b..a385d859e 100644
--- a/kcontrol/kcontrol/proxywidget.cpp
+++ b/kcontrol/kcontrol/proxywidget.cpp
@@ -120,7 +120,7 @@ public:
~ProxyContentWidget(){}
// this should be really done by qscrollview in AutoOneFit mode!
- TQSize tqsizeHint() const { return tqminimumSizeHint(); }
+ TQSize sizeHint() const { return minimumSizeHint(); }
};
@@ -144,7 +144,7 @@ ProxyView::ProxyView(KCModule *_client, const TQString&, TQWidget *parent, bool
}
client->reparent(contentWidget,0,TQPoint(0,0),true);
vbox->addWidget( client );
- vbox->activate(); // make sure we have a proper tqminimumSizeHint
+ vbox->activate(); // make sure we have a proper minimumSizeHint
addChild(contentWidget);
}